# linkml-store

An integration layer for multiple database backends

Currently this software is alpha, and has only been tested with DuckDB backends. See the Tutorial for more information.

There is also experimental support for vector-based indexing using OpenAI test embedding via the `llm` library.

The goals of this project are to provide high level access to data stored in heterogeneous databases,
with optional schema management using LinkML.
